@@ -33,5 +33,7 @@ pushd ../tests
 ./test_digest.sh
 ./test_authentication.sh
 ./test_time.sh
+./test_tcp_client.sh
+./test_udp_socket.sh
 
 popd
