@@ -21,6 +21,8 @@ pub use self::operation::Operation;
 pub use self::parameter::{Param, ParamNone, ParamTmpRef, ParamType, ParamTypes, ParamValue};
 pub use self::session::{ConnectionMethods, Session};
 pub use self::uuid::Uuid;
+pub use self::extension::*;
+pub use optee_teec_macros::{plugin_init, plugin_invoke};
 
 mod context;
 mod error;
@@ -28,3 +30,4 @@ mod operation;
 mod parameter;
 mod session;
 mod uuid;
+mod extension;
