@@ -20,6 +20,11 @@
 pub use tee_api::*;
 pub use tee_api_defines::*;
 pub use tee_api_types::*;
+pub use tee_internal_api_extensions::*;
+pub use tee_isocket::*;
+pub use tee_tcpsocket::*;
+pub use tee_udpsocket::*;
+pub use tee_ipsocket::*;
 pub use trace::*;
 pub use user_ta_header::*;
 pub use utee_syscalls::*;
@@ -28,7 +33,12 @@ pub use utee_types::*;
 mod tee_api;
 mod tee_api_defines;
 mod tee_api_types;
+mod tee_internal_api_extensions;
+mod tee_isocket;
+mod tee_tcpsocket;
+mod tee_udpsocket;
 mod trace;
 mod user_ta_header;
 mod utee_syscalls;
 mod utee_types;
+mod tee_ipsocket;
