@@ -20,6 +20,8 @@ pub use self::object::*;
 pub use self::crypto_op::*;
 pub use self::time::*;
 pub use self::arithmetical::*;
+pub use self::extension::*;
+pub use self::uuid::*;
 pub use self::parameter::{ParamType, ParamTypes, Parameter, Parameters};
 pub use optee_utee_macros::{
     ta_close_session, ta_create, ta_destroy, ta_invoke_command, ta_open_session,
@@ -34,3 +36,6 @@ pub mod object;
 pub mod crypto_op;
 pub mod time;
 pub mod arithmetical;
+pub mod extension;
+pub mod uuid;
+pub mod net;
